Dunkin' Donuts® Shop - Sign In

## Sign In or Create a Shop Account

Welcome to the Dunkin' Donuts Online Shop! You can create a separate account for online shopping. Through this separate account, you'll be able to opt-in for email communications and set up payment options just for online shopping. Please note that your email communication preferences and DD Card reload / auto recharge information, if you have already set those up on DunkinDonuts.com, are not impacted by your online shopping account. If you have any questions, please feel free to contact our Customer Service team at 877-833-2633 (877-8DD-COFFEE). Happy Shopping!

### Returning Registered Customer

This account is unique to the Dunkin' Online Shop (Shop.DunkinDonuts.com)
Your Dunkin' Donuts account and Dunkin' UpDDate email preferences are separate at www.DunkinDonuts.com.

- E-mail Address:
- Password:
- Forgot Password?

### New Customers, Create Shop Account

Benefits of Creating an Account:

- Online shop member updates and coupons
- Save favorites for future shopping
- Easy order tracking

- E-mail Address
- Create a Password:
  Minimum 8 characters, only letters and numbers.
- Confirm Password:

- ## HOW CAN WE IMPROVE?

- - If you have found something confusing or have suggestions to improve our checkout, please tell us. Sorry, we're not able to respond to comments entered below unless you provide your email address.

  - E-mail Address: (optional)
  - Phone: (optional)

  - Thank you for your feedback!

- #### Need Help?

  Call us during West Coast business hours: 1-877-833-2633
  Monday - Friday, 6am - 5pm PT | Saturday, 7am - 3pm PT

true 30 cookcookdunkindonutdev cookdunkinproduction javascript:,localhost,dunkindonuts.com false dunkindonuts.com d1 dunkindonuts.d1.sc.omtrdc.net Social Networks|facebook.com,linkedin.com,twitter.com,orkut.com,friendster.com,livejournal.com,blogspot.com,wordpress.com,friendfeed.com,myspace.com,digg.com,reddit.com,stumbleupon.com,twine.com,yelp.com,mixx.com,delicious.com,tumblr.com,disqus.com,intensedebate.com,plurk.com,slideshare.net,backtype.com,netvibes.com,mister-wong.com,diigo.com,flixster.com,youtube.com,vimeo.com,12seconds.tv,zooomr.com,identi.ca,jaiku.com,flickr.com,imeem.com,dailymotion.com,photobucket.com,fotolog.com,smugmug.com,classmates.com,myyearbook.com,mylife.com,tagged.com,brightkite.com,ning.com,bebo.com,hi5.com,yuku.com,cafemom.com,xanga.com,plus.google.com,pinterest.com Paid Search|ccaid>Email|mid>Affiliate|ccaid Paid Search|ps>Email|em>Affiliate|af>Comparison Shopping|cse>Display|dis DDAFFL DDSEOSE DDDirect false Cooking true UA-3736794-28 Dunkin' Donuts® Shop false DDSCBZ 935 false COOKING02 true 01/01/2014 true true true false false 1500606 302451 1356 ezxE1LgoKCRo false true 2146987 dunki815 2015k0